.. _convolution:

Correlation (or Convolution) and Matched Filters 
------------------------------------------------
The method was published in "Windowed State Space Filters for Peak Interference Suppression in Neural Spike Sorting" [Baeriswyl2022]_.





